@@ -276,6 +276,17 @@ public:
         m_list.push_back(item);
     }
 
+    i64 find(const T& item)
+    {
+        auto i = std::find(m_list.begin(), m_list.end(), item);
+
+        if (i == m_list.end()) {
+            return -1;
+        }
+
+        return i - m_list.begin();
+    }
+
     int __len__() const
     {
         return m_list.size();
@@ -310,6 +321,28 @@ public:
         return sum;
     }
 
+    bool __any__() const
+    {
+        for (auto& item : m_list) {
+            if (item) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
+    bool __all__() const
+    {
+        for (auto& item : m_list) {
+            if (!item) {
+                return false;
+            }
+        }
+
+        return true;
+    }
+
     bool __contains__(const T& value) const
     {
         for (auto item: m_list) {
@@ -384,6 +417,6 @@ static inline List<T> operator*(int value, const List<T>& list)
     return list * value;
 }
 
-mys::shared_ptr<List<String>> create_args(int argc, const char *argv[]);
+mys::shared_ptr<List<String>> create_args(int argc, char * const argv[]);
 
 }
