@@ -106,9 +106,9 @@ class MysLexer(RegexLexer):
             (r'\\\n', Text),
             (r'\\', Text),
             include('keywords'),
-            (r'(def)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'funcname'),
             (r'(func)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'funcname'),
             (r'(test)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'funcname'),
+            (r'(macro)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'funcname'),
             (r'(class)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'classname'),
             (r'(enum)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'classname'),
             (r'(trait)((?:\s|\\\s)+)', bygroups(Keyword, Text), 'classname'),
