@@ -1,11 +1,14 @@
 import os
+import subprocess
 from textwrap import dedent
 from textwrap import indent
 from textwrap import wrap
 
 from docutils import nodes
+from docutils.parsers.rst import directives
 from pygments import highlight
 from pygments.formatters import HtmlFormatter
+from pygments.lexers import MysCommandLexer
 from pygments.lexers import MysLexer
 from sphinx.directives import SphinxDirective
 from sphinx.locale import _
@@ -128,7 +131,7 @@ class MysFileDirective(SphinxDirective):
                         text += f'    @raises({raises})\n'
 
                     signature_string = method.signature_string(True)
-                    text += indent(f'def {signature_string}:', '    ')
+                    text += indent(f'func {signature_string}:', '    ')
                     text += '\n'
                     text += self.process_docstring(method.docstring, 8)
                     text = text.strip()
@@ -153,7 +156,7 @@ class MysFileDirective(SphinxDirective):
                         continue
 
                     text += '\n'
-                    text += f'    def {method.signature_string(True)}:'
+                    text += f'    func {method.signature_string(True)}:'
                     text += '\n'
                     text += self.process_docstring(method.docstring, 8)
                     text = text.strip()
@@ -178,7 +181,7 @@ class MysFileDirective(SphinxDirective):
                 if function.generic_types:
                     text += f'@generic({", ".join(function.generic_types)})\n'
 
-                text += f'def {function.signature_string(False)}:'
+                text += f'func {function.signature_string(False)}:'
                 text += '\n'
                 text += self.process_docstring(function.docstring, 4)
                 self.items.append(self.make_node(text))
@@ -192,8 +195,52 @@ class MysFileDirective(SphinxDirective):
             text += self.process_docstring(variable.docstring, 0)
             self.items.append(self.make_node(text))
 
+
+class MysFileContentDirective(SphinxDirective):
+    required_arguments = 1
+    has_content = True
+
+    def run(self):
+        mys_file_path = os.path.join('..', self.arguments[0])
+
+        with open(mys_file_path, 'r') as fin:
+            source = fin.read()
+
+        return [nodes.raw('',
+                          highlight(source, MysLexer(), HtmlFormatter()),
+                          format='html')]
+
+
+class MysRunDirective(SphinxDirective):
+    required_arguments = 1
+    has_content = True
+    option_spec = {
+        'arguments': directives.unchanged
+    }
+
+    def run(self):
+        example_path = os.path.join('..', self.arguments[0])
+        arguments = self.options.get('arguments', '').split(' ')
+        subprocess.run(['mys', '-C', example_path, 'clean'], check=True)
+        command = ['mys', '-C', example_path, 'run'] + arguments
+        proc = subprocess.run(command,
+                              stdout=subprocess.PIPE,
+                              text=True,
+                              check=True,
+                              timeout=180)
+        output = '❯ ' + ' '.join(command).replace('../', '') + '\n'
+        output += proc.stdout
+
+        return [nodes.raw('',
+                          highlight(output, MysCommandLexer(), HtmlFormatter()),
+                          format='html')]
+
+
 def setup(app):
     app.add_directive('mysfile', MysFileDirective)
+    app.add_directive('mysfilecontent', MysFileContentDirective)
+    # Not very safe right now.
+    # app.add_directive('mysrun', MysRunDirective)
 
     return {
         'version': __version__,
