@@ -44,19 +44,14 @@ class TypeVisitor(ast.NodeVisitor):
 
     def visit_Subscript(self, node):
         value = self.visit(node.value)
+        types = self.visit(node.slice)
 
-        if value == 'lazy':
-            # Not lazy right now.
-            return self.visit(node.slice)
+        if isinstance(node.slice, ast.Name):
+            types = [types]
         else:
-            types = self.visit(node.slice)
+            types = list(types)
 
-            if isinstance(node.slice, ast.Name):
-                types = [types]
-            else:
-                types = list(types)
-
-            return GenericType(value, types, node)
+        return GenericType(value, types, node)
 
 
 class FormatDefaultVisitor(ast.NodeVisitor):
@@ -111,6 +106,7 @@ class Function:
                  generic_types,
                  raises,
                  is_test,
+                 is_macro,
                  args,
                  returns,
                  node,
@@ -121,6 +117,7 @@ class Function:
         self.generic_types = generic_types
         self.raises = raises
         self.is_test = is_test
+        self.is_macro = is_macro
         self.args = args
         self.returns = returns
         self.node = node
@@ -162,7 +159,7 @@ class Function:
                     params = ['self']
 
             params_string = indent(',\n'.join(params),
-                                   ' ' * (len(self.name) + 5)).strip()
+                                   ' ' * (len(self.name) + 6)).strip()
         else:
             if method:
                 if params_string:
@@ -348,9 +345,12 @@ class Definitions:
         value.module_name = self.module_name
         functions = self.functions[name]
 
-        if functions:
-            value.is_overloaded = True
-            functions[0].is_overloaded = True
+        if functions and not value.is_test:
+            if any(not function.is_test for function in functions):
+                value.is_overloaded = True
+
+                for function in functions:
+                    function.is_overloaded = True
 
         functions.append(value)
 
@@ -422,7 +422,7 @@ def is_method(node):
 
 class FunctionVisitor(TypeVisitor):
 
-    ALLOWED_DECORATORS = ['generic', 'test', 'raises']
+    ALLOWED_DECORATORS = ['generic', 'test', 'raises', 'macro']
 
     def visit_arg(self, node):
         if node.annotation is None:
@@ -446,11 +446,16 @@ class FunctionVisitor(TypeVisitor):
         return args[::-1]
 
     def visit_FunctionDef(self, node):
-        if not is_snake_case(node.name):
-            raise CompileError("function names must be snake case", node)
-
         decorators = visit_decorator_list(node.decorator_list,
                                           self.ALLOWED_DECORATORS)
+
+        if 'macro' in decorators:
+            if not is_upper_snake_case(node.name):
+                raise CompileError("macro names must be upper case snake case", node)
+        else:
+            if not is_snake_case(node.name):
+                raise CompileError("function names must be snake case", node)
+
         args = self.visit(node.args)
 
         if node.returns is None:
@@ -467,6 +472,7 @@ class FunctionVisitor(TypeVisitor):
                         decorators.get('generic', []),
                         decorators.get('raises', []),
                         'test' in decorators,
+                        'macro' in decorators,
                         args,
                         returns,
                         node,
@@ -477,7 +483,7 @@ class FunctionVisitor(TypeVisitor):
 
 class MethodVisitor(FunctionVisitor):
 
-    ALLOWED_DECORATORS = ['generic', 'raises']
+    ALLOWED_DECORATORS = ['generic', 'raises', 'macro']
 
     def visit_arguments(self, node):
         args = []
@@ -553,6 +559,11 @@ def visit_decorator_list(decorator_list, allowed_decorators):
                 raise CompileError("@raises requires at least one error", decorator)
 
             decorators['raises'] = values
+        elif name == 'macro':
+            if values:
+                raise CompileError("no parameters expected", decorator)
+
+            decorators['macro'] = None
 
     return decorators
 
