@@ -28,6 +28,8 @@ def is_allowed_dict_key_type(mys_type):
         return True
     elif mys_type == 'string':
         return True
+    elif mys_type == 'bytes':
+        return True
 
     return False
 
@@ -83,6 +85,8 @@ class ValueCheckTypeVisitor:
         if isinstance(mys_type, set) and len(node.keys) == 0:
             item_mys_type = list(mys_type)[0]
             item_cpp_type = self.mys_to_cpp_type(item_mys_type)
+            self.context.mys_type = mys_type
+
             return make_shared_set(item_cpp_type, '')
 
         if not isinstance(mys_type, dict):
@@ -92,8 +96,8 @@ class ValueCheckTypeVisitor:
 
         key_mys_type, value_mys_type = split_dict_mys_type(mys_type)
 
-        if not is_allowed_dict_key_type(key_mys_type):
-            raise CompileError("invalid key type", node)
+        #if not is_allowed_dict_key_type(key_mys_type):
+        #    raise CompileError("invalid key type", node)
 
         keys = []
         values = []
