@@ -57,28 +57,28 @@ class Test(TestCase):
             except SystemExit:
                 pass
 
-            self.run_safe_test_none('test_class_none_1')
-            self.run_safe_test_none('test_class_none_2')
-            self.run_safe_test_none('test_compare_lists_3')
-            self.run_safe_test_none('test_add_lists')
-            self.run_safe_test_none('test_list_acces_none')
-            self.run_safe_test_none('test_list_len_of_none')
-            self.run_safe_test_none('test_compare_tuples_3')
-            self.run_safe_test_none('test_tuple_acces_none')
-            self.run_safe_test_none('test_tuple_unpack_in_for_loop_none_element')
-            self.run_safe_test_none('test_string_none')
-            self.run_safe_test_none('test_string_len_of_none')
-            self.run_safe_test_none('test_compare_dicts_3')
-            self.run_safe_test_none('test_dict_acces_none')
-            self.run_safe_test_none('test_dict_len_of_none')
-            self.run_safe_test_none('test_set_none')
-            self.run_safe_test_index('test_bytes_index',
+            self.run_safe_test_none('class_none_1')
+            self.run_safe_test_none('class_none_2')
+            self.run_safe_test_none('compare_lists_3')
+            self.run_safe_test_none('add_lists')
+            self.run_safe_test_none('list_acces_none')
+            self.run_safe_test_none('list_len_of_none')
+            self.run_safe_test_none('compare_tuples_3')
+            self.run_safe_test_none('tuple_acces_none')
+            self.run_safe_test_none('tuple_unpack_in_for_loop_none_element')
+            self.run_safe_test_none('string_none')
+            self.run_safe_test_none('string_len_of_none')
+            self.run_safe_test_none('compare_dicts_3')
+            self.run_safe_test_none('dict_acces_none')
+            self.run_safe_test_none('dict_len_of_none')
+            self.run_safe_test_none('set_none')
+            self.run_safe_test_index('bytes_index',
                                      'Bytes index -99997 is out of range.')
-            self.run_safe_test_index('test_list_pop_index',
+            self.run_safe_test_index('list_pop_index',
                                      'Pop index 1000 is out of range.')
-            self.run_safe_test_index('test_negative_list_index',
+            self.run_safe_test_index('negative_list_index',
                                      'List index -99996 is out of range.')
-            self.run_safe_test_index('test_string_get_char_at_index',
+            self.run_safe_test_index('string_get_char_at_index',
                                      'String index -99994 is out of range.')
 
     def test_unsafe(self):
@@ -94,26 +94,26 @@ class Test(TestCase):
             except SystemExit:
                 pass
 
-            self.run_unsafe_test_none('test_class_none_1')
-            self.run_unsafe_test_none('test_compare_lists_3')
-            self.run_unsafe_test_none('test_add_lists')
-            self.run_unsafe_test_none('test_list_acces_none')
-            self.run_unsafe_test_none('test_list_len_of_none')
-            self.run_unsafe_test_none('test_compare_tuples_3')
-            self.run_unsafe_test_none('test_tuple_acces_none')
-            self.run_unsafe_test_none('test_tuple_unpack_in_for_loop_none_element')
-            self.run_unsafe_test_none('test_string_none')
-            self.run_unsafe_test_none('test_string_len_of_none')
-            self.run_unsafe_test_none('test_compare_dicts_3')
-            self.run_unsafe_test_none('test_dict_acces_none')
-            self.run_unsafe_test_none('test_dict_len_of_none')
-            self.run_unsafe_test_none('test_set_none')
-            self.run_unsafe_test_index('test_bytes_index', 'bytes index out of range')
-            self.run_unsafe_test_index('test_list_pop_index',
+            self.run_unsafe_test_none('class_none_1')
+            self.run_unsafe_test_none('compare_lists_3')
+            self.run_unsafe_test_none('add_lists')
+            self.run_unsafe_test_none('list_acces_none')
+            self.run_unsafe_test_none('list_len_of_none')
+            self.run_unsafe_test_none('compare_tuples_3')
+            self.run_unsafe_test_none('tuple_acces_none')
+            self.run_unsafe_test_none('tuple_unpack_in_for_loop_none_element')
+            self.run_unsafe_test_none('string_none')
+            self.run_unsafe_test_none('string_len_of_none')
+            self.run_unsafe_test_none('compare_dicts_3')
+            self.run_unsafe_test_none('dict_acces_none')
+            self.run_unsafe_test_none('dict_len_of_none')
+            self.run_unsafe_test_none('set_none')
+            self.run_unsafe_test_index('bytes_index', 'bytes index out of range')
+            self.run_unsafe_test_index('list_pop_index',
                                        'pop index out of range')
-            self.run_unsafe_test_index('test_negative_list_index',
+            self.run_unsafe_test_index('negative_list_index',
                                        'list index out of range')
-            self.run_unsafe_test_index('test_string_get_char_at_index',
+            self.run_unsafe_test_index('string_get_char_at_index',
                                        'string index out of range')
 
     def test_unsafe_build_run_test(self):
