@@ -9,7 +9,7 @@ class Test(TestCase):
     def test_invalid_decorator_value(self):
         self.assert_transpile_raises(
             '@raises(A(B))\n'
-            'def foo():\n'
+            'func foo():\n'
             '    pass\n',
             '  File "", line 1\n'
             '    @raises(A(B))\n'
@@ -19,7 +19,7 @@ class Test(TestCase):
     def test_invalid_decorator_value_syntax(self):
         self.assert_transpile_raises(
             '@raises[A]\n'
-            'def foo():\n'
+            'func foo():\n'
             '    pass\n',
             '  File "", line 1\n'
             '    @raises[A]\n'
@@ -28,7 +28,7 @@ class Test(TestCase):
 
     def test_inferred_type_combined_integers_assignment_too_big(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    value = (0xffffffffffffffff + 1)\n'
             '    print(value)\n',
             '  File "", line 2\n'
@@ -37,8 +37,7 @@ class Test(TestCase):
             "CompileError: integer literal out of range for 'i64'\n")
 
     def test_test_functions_not_in_header(self):
-        header = transpile_header('@test\n'
-                                  'def test_foo():\n'
+        header = transpile_header('test test_foo():\n'
                                   '    pass\n',
                                   module_hpp='foo/lib.mys.hpp')
 
@@ -46,7 +45,7 @@ class Test(TestCase):
 
     def test_return_i64_from_function_returning_string(self):
         self.assert_transpile_raises(
-            'def foo() -> string:\n'
+            'func foo() -> string:\n'
             '    return True',
             '  File "", line 2\n'
             '        return True\n'
@@ -55,7 +54,7 @@ class Test(TestCase):
 
     def test_return_list_from_function_returning_tuple(self):
         self.assert_transpile_raises(
-            'def foo() -> (bool, i64):\n'
+            'func foo() -> (bool, i64):\n'
             '    return [1]',
             '  File "", line 2\n'
             '        return [1]\n'
@@ -64,7 +63,7 @@ class Test(TestCase):
 
     def test_return_tuple_from_function_returning_list(self):
         self.assert_transpile_raises(
-            'def foo() -> [bool]:\n'
+            'func foo() -> [bool]:\n'
             '    return (1, True)',
             '  File "", line 2\n'
             '        return (1, True)\n'
@@ -73,9 +72,9 @@ class Test(TestCase):
 
     def test_wrong_number_of_function_parameters(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    pass\n'
-            'def bar():\n'
+            'func bar():\n'
             '    foo(1)\n',
             '  File "", line 4\n'
             '        foo(1)\n'
@@ -84,9 +83,9 @@ class Test(TestCase):
 
     def test_wrong_function_parameter_type(self):
         self.assert_transpile_raises(
-            'def foo(a: string):\n'
+            'func foo(a: string):\n'
             '    pass\n'
-            'def bar():\n'
+            'func bar():\n'
             '    foo(True)\n',
             '  File "", line 4\n'
             '        foo(True)\n'
@@ -132,7 +131,7 @@ class Test(TestCase):
 
     def test_assign_negative_number_to_u32(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    k: u32 = -1\n'
             '    print(k)\n',
             '  File "", line 2\n'
@@ -141,7 +140,7 @@ class Test(TestCase):
             "CompileError: integer literal out of range for 'u32'\n")
 
     def test_assign_positive_number_to_u32(self):
-        source = transpile_source('def foo():\n'
+        source = transpile_source('func foo():\n'
                                   '    i: u32 = +1\n'
                                   '    j: u32 = --1\n'
                                   '    print(i, j)\n')
@@ -151,7 +150,7 @@ class Test(TestCase):
 
     def test_reassign_negative_number_to_u32(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    i: u32 = 0\n'
             '    i = -1\n'
             '    print(i)\n',
@@ -162,7 +161,7 @@ class Test(TestCase):
 
     def test_arithmetics_on_mix_of_literals_and_known_types_too_big(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    k: i64 = 1\n'
             '    value = (0xffffffffffffffff + k)\n'
             '    print(value)\n',
@@ -173,7 +172,7 @@ class Test(TestCase):
 
     def test_arithmetics_on_mix_of_literals_and_known_types_negative(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    value: u8 = (-1 * 5)\n'
             '    print(value)\n',
             '  File "", line 2\n'
@@ -182,7 +181,7 @@ class Test(TestCase):
             "CompileError: integer literal out of range for 'u8'\n")
 
     def test_change_integer_type(self):
-        source = transpile_source('def foo():\n'
+        source = transpile_source('func foo():\n'
                                   '    value = (i8(-1) * i8(u32(5)))\n'
                                   '    print(value)\n')
 
@@ -190,7 +189,7 @@ class Test(TestCase):
 
     def test_change_integer_type_error(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    value = (i8(-1) * u32(5))\n'
             '    print(value)\n',
             '  File "", line 2\n'
@@ -199,9 +198,9 @@ class Test(TestCase):
             "CompileError: types 'i8' and 'u32' differs\n")
 
     def test_function_call(self):
-        source = transpile_source('def foo(a: i32, b: f32):\n'
+        source = transpile_source('func foo(a: i32, b: f32):\n'
                                   '    print(a, b)\n'
-                                  'def bar():\n'
+                                  'func bar():\n'
                                   '    foo(1, 2.1)\n')
 
         self.assert_in('foo(1, 2.1);', source)
@@ -209,9 +208,9 @@ class Test(TestCase):
     def test_tuple_unpack_variable_defined_other_type(self):
         self.assert_transpile_raises(
             'class Foo:\n'
-            '    def foo(self) -> (bool, i64):\n'
+            '    func foo(self) -> (bool, i64):\n'
             '        return (True, -5)\n'
-            'def foo():\n'
+            'func foo():\n'
             '    v = Foo()\n'
             '    b: string = ""\n'
             '    a, b = v.foo()\n',
@@ -222,7 +221,7 @@ class Test(TestCase):
 
     def test_tuple_unpack_integer(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    a, b = 1\n'
             '    print(a, b)\n',
             '  File "", line 2\n'
@@ -232,7 +231,7 @@ class Test(TestCase):
 
     def test_type_error_1(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    a: u16 = 1\n'
             '    b: u32 = 1\n'
             '    c = b - a\n'
@@ -244,7 +243,7 @@ class Test(TestCase):
 
     def test_type_error_2(self):
         self.assert_transpile_raises(
-            'def foo(a: i64):\n'
+            'func foo(a: i64):\n'
             '    b: u64 = a\n'
             '    print(b)\n',
             '  File "", line 2\n'
@@ -254,9 +253,9 @@ class Test(TestCase):
 
     def test_type_error_3(self):
         self.assert_transpile_raises(
-            'def bar() -> string:\n'
+            'func bar() -> string:\n'
             '    return ""\n'
-            'def foo():\n'
+            'func foo():\n'
             '    b: u64 = bar()\n'
             '    print(b)\n',
             '  File "", line 4\n'
@@ -266,7 +265,7 @@ class Test(TestCase):
 
     def test_type_error_4(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    a: u32 = 1\n'
             '    b = a - [1]\n'
             '    print(b)\n',
@@ -278,7 +277,7 @@ class Test(TestCase):
 
     def test_type_error_5(self):
         self.assert_transpile_raises(
-            'def foo() -> bool:\n'
+            'func foo() -> bool:\n'
             '    return\n',
             '  File "", line 2\n'
             '        return\n'
@@ -287,7 +286,7 @@ class Test(TestCase):
 
     def test_type_error_6(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    return 1\n',
             '  File "", line 2\n'
             '        return 1\n'
@@ -296,7 +295,7 @@ class Test(TestCase):
 
     def test_bool_op_1(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    if True or None:\n'
             '        pass\n',
             '  File "", line 2\n'
@@ -306,7 +305,7 @@ class Test(TestCase):
 
     def test_bool_op_2(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    if True or False and 1:\n'
             '        pass\n',
             '  File "", line 2\n'
@@ -315,7 +314,7 @@ class Test(TestCase):
             "CompileError: expected a 'bool', got a 'i64'\n")
 
     def test_docstring(self):
-        source = transpile_source('def foo():\n'
+        source = transpile_source('func foo():\n'
                                   '    "Hi!"\n')
 
         self.assert_in('void foo(void)\n'
@@ -343,7 +342,7 @@ class Test(TestCase):
 
     def test_assign_to_wrong_type(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    a = 1\n'
             '    a = ""\n',
             '  File "", line 3\n'
@@ -353,7 +352,7 @@ class Test(TestCase):
 
     def test_min_wrong_types(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    print(min(u8(1), u8(2), i8(2)))\n',
             '  File "", line 2\n'
             '        print(min(u8(1), u8(2), i8(2)))\n'
@@ -362,7 +361,7 @@ class Test(TestCase):
 
     def test_min_no_args(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    print(min())\n',
             '  File "", line 2\n'
             '        print(min())\n'
@@ -371,7 +370,7 @@ class Test(TestCase):
 
     def test_min_wrong_return_type(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    assert min(1, 2) == i8(1)\n',
             '  File "", line 2\n'
             '        assert min(1, 2) == i8(1)\n'
@@ -380,7 +379,7 @@ class Test(TestCase):
 
     def test_max_wrong_types(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    print(max(i8(1), i8(2), u8(2)))\n',
             '  File "", line 2\n'
             '        print(max(i8(1), i8(2), u8(2)))\n'
@@ -389,7 +388,7 @@ class Test(TestCase):
 
     def test_max_no_args(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    print(max())\n',
             '  File "", line 2\n'
             '        print(max())\n'
@@ -398,7 +397,7 @@ class Test(TestCase):
 
     def test_max_wrong_return_type(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    assert max(u8(1), 2) == i8(1)\n',
             '  File "", line 2\n'
             '        assert max(u8(1), 2) == i8(1)\n'
@@ -407,7 +406,7 @@ class Test(TestCase):
 
     def test_len_no_params(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    print(len())\n',
             '  File "", line 2\n'
             '        print(len())\n'
@@ -416,7 +415,7 @@ class Test(TestCase):
 
     def test_len_two_params(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    print(len(1, 2))\n',
             '  File "", line 2\n'
             '        print(len(1, 2))\n'
@@ -425,7 +424,7 @@ class Test(TestCase):
 
     def test_len_compare_to_non_u64(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    assert len("") == i8(0)\n',
             '  File "", line 2\n'
             '        assert len("") == i8(0)\n'
@@ -434,7 +433,7 @@ class Test(TestCase):
 
     def test_str_compare_to_non_string(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    assert str(0) == i8(0)\n',
             '  File "", line 2\n'
             '        assert str(0) == i8(0)\n'
@@ -443,7 +442,7 @@ class Test(TestCase):
 
     def test_tuple_index_1(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    a = 1\n'
             '    v = (1, "b")\n'
             '    print(v[a])\n',
@@ -454,7 +453,7 @@ class Test(TestCase):
 
     def test_tuple_index_2(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v = (1, "b")\n'
             '    print(v[1 / 2])\n',
             '  File "", line 3\n'
@@ -464,7 +463,7 @@ class Test(TestCase):
 
     def test_tuple_item_assign_1(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v = (1, "b")\n'
             '    v[0] = "ff"\n',
             '  File "", line 3\n'
@@ -474,7 +473,7 @@ class Test(TestCase):
 
     def test_tuple_item_assign_2(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    a, b, c = (1, "b")\n',
             '  File "", line 2\n'
             '        a, b, c = (1, "b")\n'
@@ -483,7 +482,7 @@ class Test(TestCase):
 
     def test_return_nones_as_bool_in_tuple(self):
         self.assert_transpile_raises(
-            'def foo() -> (bool, bool):\n'
+            'func foo() -> (bool, bool):\n'
             '    return (None, None)\n',
             '  File "", line 2\n'
             '        return (None, None)\n'
@@ -492,7 +491,7 @@ class Test(TestCase):
 
     def test_return_wrong_integer_in_tuple(self):
         self.assert_transpile_raises(
-            'def foo() -> (bool, u8, string):\n'
+            'func foo() -> (bool, u8, string):\n'
             '    return (True, i8(1), "")\n',
             '  File "", line 2\n'
             '        return (True, i8(1), "")\n'
@@ -501,7 +500,7 @@ class Test(TestCase):
 
     def test_return_none_as_bool(self):
         self.assert_transpile_raises(
-            'def foo() -> bool:\n'
+            'func foo() -> bool:\n'
             '    return None\n',
             '  File "", line 2\n'
             '        return None\n'
@@ -518,7 +517,7 @@ class Test(TestCase):
 
     def test_return_short_tuple(self):
         self.assert_transpile_raises(
-            'def foo() -> (bool, bool):\n'
+            'func foo() -> (bool, bool):\n'
             '    return (True, )\n',
             '  File "", line 2\n'
             '        return (True, )\n'
@@ -527,7 +526,7 @@ class Test(TestCase):
 
     def test_tuple_index_out_of_range(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    v = ("", 1)\n'
             '    print(v[2])\n',
             '  File "", line 3\n'
@@ -537,9 +536,9 @@ class Test(TestCase):
 
     def test_assign_to_function_call(self):
         with self.assertRaises(Exception) as cm:
-            transpile_source('def bar() -> i32:\n'
+            transpile_source('func bar() -> i32:\n'
                              '    return 1\n'
-                             'def foo():\n'
+                             'func foo():\n'
                              '    bar() = 1\n')
 
         self.assertEqual(
@@ -553,7 +552,7 @@ class Test(TestCase):
         # At least true for now...
         for name in ['range', 'enumerate', 'zip', 'slice', 'reversed']:
             self.assert_transpile_raises(
-                'def foo():\n'
+                'func foo():\n'
                 f'    v = {name}([1, 4])\n'
                 '    print(v)',
                 '  File "", line 2\n'
@@ -563,14 +562,14 @@ class Test(TestCase):
 
     def test_main_in_non_main_file(self):
         with self.assertRaises(Exception) as cm:
-            transpile_source('def main():\n'
+            transpile_source('func main():\n'
                              '    pass\n')
 
         self.assertEqual(str(cm.exception), 'main() is only allowed in main.mys')
 
     def test_no_main_in_main_file(self):
         with self.assertRaises(Exception) as cm:
-            transpile_source('def foo():\n'
+            transpile_source('func foo():\n'
                              '    pass\n',
                              has_main=True)
 
@@ -578,9 +577,9 @@ class Test(TestCase):
 
     def test_call_void_1(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    pass\n'
-            'def bar():\n'
+            'func bar():\n'
             '    foo().bar()\n',
             '  File "", line 4\n'
             '        foo().bar()\n'
@@ -589,9 +588,9 @@ class Test(TestCase):
 
     def test_call_void_2(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    pass\n'
-            'def bar():\n'
+            'func bar():\n'
             '    print(foo())\n',
             '  File "", line 4\n'
             '        print(foo())\n'
@@ -600,7 +599,7 @@ class Test(TestCase):
 
     def test_bare_integer(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    1\n',
             '  File "", line 2\n'
             '        1\n'
@@ -609,7 +608,7 @@ class Test(TestCase):
 
     def test_bare_float(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    2.0\n',
             '  File "", line 2\n'
             '        2.0\n'
@@ -618,7 +617,7 @@ class Test(TestCase):
 
     def test_bare_not(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    not True\n',
             '  File "", line 2\n'
             '        not True\n'
@@ -627,7 +626,7 @@ class Test(TestCase):
 
     def test_bare_add(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    1 + 2\n',
             '  File "", line 2\n'
             '        1 + 2\n'
@@ -636,7 +635,7 @@ class Test(TestCase):
 
     def test_bare_name(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    a: i32 = 0\n'
             '    a\n',
             '  File "", line 3\n'
@@ -646,7 +645,7 @@ class Test(TestCase):
 
     def test_not_only_allowed_on_bool(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    print(not "hi")\n',
             '  File "", line 2\n'
             '        print(not "hi")\n'
@@ -655,7 +654,7 @@ class Test(TestCase):
 
     def test_negative_bool(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    print(-True)\n',
             '  File "", line 2\n'
             '        print(-True)\n'
@@ -664,9 +663,9 @@ class Test(TestCase):
 
     def test_named_parameter_wrong_name(self):
         self.assert_transpile_raises(
-            'def foo(a: bool):\n'
+            'func foo(a: bool):\n'
             '    print(a)\n'
-            'def bar():\n'
+            'func bar():\n'
             '    foo(b=True)\n',
             '  File "", line 4\n'
             '        foo(b=True)\n'
@@ -675,9 +674,9 @@ class Test(TestCase):
 
     def test_named_parameter_twice(self):
         self.assert_transpile_raises(
-            'def foo(a: bool, b: i64):\n'
+            'func foo(a: bool, b: i64):\n'
             '    print(a, b)\n'
-            'def bar():\n'
+            'func bar():\n'
             '    foo(b=True, b=1)\n',
             '  File "", line 4\n'
             '        foo(b=True, b=1)\n'
@@ -686,9 +685,9 @@ class Test(TestCase):
 
     def test_both_regular_and_named_parameter(self):
         self.assert_transpile_raises(
-            'def foo(a: bool):\n'
+            'func foo(a: bool):\n'
             '    print(a)\n'
-            'def bar():\n'
+            'func bar():\n'
             '    foo(True, a=True)\n',
             '  File "", line 4\n'
             '        foo(True, a=True)\n'
@@ -697,9 +696,9 @@ class Test(TestCase):
 
     def test_both_regular_and_named_parameter_2(self):
         self.assert_transpile_raises(
-            'def foo(a: (bool, string)):\n'
+            'func foo(a: (bool, string)):\n'
             '    print(a)\n'
-            'def bar():\n'
+            'func bar():\n'
             '    foo(True, a=True)\n',
             '  File "", line 4\n'
             '        foo(True, a=True)\n'
@@ -708,9 +707,9 @@ class Test(TestCase):
 
     def test_named_parameter_before_regular(self):
         with self.assertRaises(Exception) as cm:
-            transpile_source('def foo(a: bool, b: i64):\n'
+            transpile_source('func foo(a: bool, b: i64):\n'
                              '    print(a, b)\n'
-                             'def bar():\n'
+                             'func bar():\n'
                              '    foo(a=True, 1)\n')
 
         self.assertEqual(
@@ -722,9 +721,9 @@ class Test(TestCase):
 
     def test_name_clash(self):
         self.assert_transpile_raises(
-            'def bar():\n'
+            'func bar():\n'
             '    pass\n'
-            'def foo():\n'
+            'func foo():\n'
             '    bar = 1\n'
             '    print(bar)\n',
             '  File "", line 4\n'
@@ -733,41 +732,41 @@ class Test(TestCase):
             "CompileError: redefining 'bar'\n")
 
     def test_inline_constant_default_bool_parameter_value(self):
-        source = transpile_source('def foo(a: bool = True):\n'
+        source = transpile_source('func foo(a: bool = True):\n'
                                   '    pass\n'
-                                  'def bar():\n'
+                                  'func bar():\n'
                                   '    foo()\n')
 
         self.assert_in('foo(mys::Bool(true))', source)
 
     def test_inline_constant_default_u8_parameter_value(self):
-        source = transpile_source('def foo(a: u8 = 1):\n'
+        source = transpile_source('func foo(a: u8 = 1):\n'
                                   '    pass\n'
-                                  'def bar():\n'
+                                  'func bar():\n'
                                   '    foo()\n')
 
         self.assert_in('foo(1)', source)
 
     def test_inline_constant_default_i8_parameter_value(self):
-        source = transpile_source('def foo(a: i8 = -1):\n'
+        source = transpile_source('func foo(a: i8 = -1):\n'
                                   '    pass\n'
-                                  'def bar():\n'
+                                  'func bar():\n'
                                   '    foo()\n')
 
         self.assert_in('foo(-1)', source)
 
     def test_inline_constant_default_f64_parameter_value(self):
-        source = transpile_source('def foo(a: f64 = 5.1):\n'
+        source = transpile_source('func foo(a: f64 = 5.1):\n'
                                   '    pass\n'
-                                  'def bar():\n'
+                                  'func bar():\n'
                                   '    foo()\n')
 
         self.assert_in('foo(5.1)', source)
 
     def test_inline_constant_default_string_parameter_value(self):
-        source = transpile_source('def foo(a: string = "hi"):\n'
+        source = transpile_source('func foo(a: string = "hi"):\n'
                                   '    pass\n'
-                                  'def bar():\n'
+                                  'func bar():\n'
                                   '    foo()\n')
 
         self.assert_in('foo(mys::String("hi"))', source)
@@ -775,17 +774,17 @@ class Test(TestCase):
     def test_inline_constant_default_class_parameter_value_none(self):
         source = transpile_source('class Foo:\n'
                                   '    pass\n'
-                                  'def foo(a: Foo = None):\n'
+                                  'func foo(a: Foo = None):\n'
                                   '    pass\n'
-                                  'def bar():\n'
+                                  'func bar():\n'
                                   '    foo()\n')
 
         self.assert_in('foo(nullptr)', source)
 
     def test_inline_constant_default_tuple_parameter_value_none(self):
-        source = transpile_source('def foo(a: (i8, string) = None):\n'
+        source = transpile_source('func foo(a: (i8, string) = None):\n'
                                   '    pass\n'
-                                  'def bar():\n'
+                                  'func bar():\n'
                                   '    foo()\n')
 
         self.assert_in('foo(nullptr)', source)
@@ -793,16 +792,16 @@ class Test(TestCase):
     def test_not_inline_constant_default_class_parameter_value_not_none(self):
         source = transpile_source('class Foo:\n'
                                   '    pass\n'
-                                  'def foo(a: Foo = Foo()):\n'
+                                  'func foo(a: Foo = Foo()):\n'
                                   '    pass\n'
-                                  'def bar():\n'
+                                  'func bar():\n'
                                   '    foo()\n')
 
         self.assert_in('foo(mys::foo::lib::foo_a_default())', source)
 
     def test_aug_assign_wrong_integer_types(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    x: i32 = 0\n'
             '    x += i8(1)\n',
             '  File "", line 3\n'
@@ -812,25 +811,25 @@ class Test(TestCase):
 
     def test_undefined_type_as_function_parameter(self):
         self.assert_transpile_raises(
-            'def add(a: Foo):\n'
+            'func add(a: Foo):\n'
             '    pass\n',
             '  File "", line 1\n'
-            '    def add(a: Foo):\n'
-            '               ^\n'
+            '    func add(a: Foo):\n'
+            '                ^\n'
             "CompileError: undefined type 'Foo'\n")
 
     def test_undefined_function_return_type(self):
         self.assert_transpile_raises(
-            'def add() -> Foo:\n'
+            'func add() -> Foo:\n'
             '    return None\n',
             '  File "", line 1\n'
-            '    def add() -> Foo:\n'
-            '                 ^\n'
+            '    func add() -> Foo:\n'
+            '                  ^\n'
             "CompileError: undefined type 'Foo'\n")
 
     def test_power_f64_and_i64(self):
         self.assert_transpile_raises(
-            'def foo():\n'
+            'func foo():\n'
             '    print(2.0 ** 3)\n',
             '  File "", line 2\n'
             '        print(2.0 ** 3)\n'
@@ -843,9 +842,9 @@ class Test(TestCase):
     #     self.assert_transpile_raises(
     #         'class Bar:\n'
     #         '    text: string\n'
-    #         '    def text(self) -> string:\n'
+    #         '    func text(self) -> string:\n'
     #         '        return self.text\n',
     #         '  File "", line 1\n'
-    #         '    def add() -> Foo:\n'
+    #         '    func add() -> Foo:\n'
     #         '                 ^\n'
     #         "CompileError: undefined type 'Foo'\n")
